# Contributing to Wn

Thanks for helping to make Wn better!

**Quick Links:**

- [Report a bug or request a features](https://github.com/goodmami/wn/issues/new)
- [View documentation](https://wn.readthedocs.io/)

**Developer Information:**

- Versioning scheme: [Semantic Versioning](https://semver.org/)
- Branching scheme: [GitHub Flow](https://guides.github.com/introduction/flow/)
- Changelog: [keep a changelog](https://keepachangelog.com/en/1.0.0/)
- Documentation framework: [Sphinx](https://www.sphinx-doc.org/)
- Docstring style: [Google Python Style Guide](https://google.github.io/styleguide/pyguide.html#38-comments-and-docstrings) (via [sphinx.ext.napoleon](https://www.sphinx-doc.org/en/master/usage/extensions/napoleon.html))
- Testing framework: [pytest](https://pytest.org/)
- Packaging framework: [flit](https://flit.readthedocs.io/en/latest/)
- Coding style: [PEP-8](https://www.python.org/dev/peps/pep-0008/)
- Type checking: [Mypy](http://mypy-lang.org/)


## Get Help

Confused about wordnets? See the [Global Wordnet Association
Documentation](https://globalwordnet.github.io/gwadoc/)

Having trouble with using Wn? [Raise an
issue](https://github.com/goodmami/wn/issues/new)

## Report a Bug

When reporting a bug, please provide enough information for someone to
reproduce the problem. This might include the version of Python you're
running, the version of Wn you have installed, the wordnet lexicons
you have installed, and possibly the platform (Linux, Windows, macOS)
you're on. Please give a minimal working example that illustrates the
problem.

## Request a Feature

If there's a feature that you think would make a good addition to Wn,
raise an issue describing what the feature is and what problems it
would address.

## Guidelines for Contributing

See the "developer information" above for a brief description of
guidelines and conventions used in Wn. If you have a fix, please
submit a pull request to the `main` branch.
